pub enum TrackedProcessState {
None,
Seen,
Busy,
Unseen,
}Variants
None
No configured tracked process is running in the pane.
Seen
A tracked process previously needed attention and that attention was acknowledged by focusing the pane.
Busy
A tracked process is running, with no pending attention signal.
Unseen
A tracked process needs attention and has not yet been acknowledged by focusing the pane.