pub struct AttachAccepted {
pub layout: LayoutSnapshot,
pub pane_regions: PaneRegionsSnapshot,
}Fields
layout: LayoutSnapshotpane_regions: PaneRegionsSnapshotTrait Implementations
Sourceimpl Archive for AttachAcceptedwhere
LayoutSnapshot: Archive,
PaneRegionsSnapshot: Archive,
impl Archive for AttachAcceptedwhere
LayoutSnapshot: Archive,
PaneRegionsSnapshot: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedAttachAccepted
type Archived = ArchivedAttachAccepted
The archived representation of this type. Read more
Sourcetype Resolver = AttachAcceptedResolver
type Resolver = AttachAcceptedResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for AttachAccepted
impl Clone for AttachAccepted
Sourcefn clone(&self) -> AttachAccepted
fn clone(&self) -> AttachAccepted
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttachAccepted
impl Debug for AttachAccepted
Sourceimpl<__D: Fallible + ?Sized> Deserialize<AttachAccepted, __D> for Archived<AttachAccepted>where
LayoutSnapshot: Archive,
<LayoutSnapshot as Archive>::Archived: Deserialize<LayoutSnapshot, __D>,
PaneRegionsSnapshot: Archive,
<PaneRegionsSnapshot as Archive>::Archived: Deserialize<PaneRegionsSnapshot, __D>,
impl<__D: Fallible + ?Sized> Deserialize<AttachAccepted, __D> for Archived<AttachAccepted>where
LayoutSnapshot: Archive,
<LayoutSnapshot as Archive>::Archived: Deserialize<LayoutSnapshot, __D>,
PaneRegionsSnapshot: Archive,
<PaneRegionsSnapshot as Archive>::Archived: Deserialize<PaneRegionsSnapshot, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<AttachAccepted, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<AttachAccepted, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Eq for AttachAccepted
Sourceimpl PartialEq for AttachAccepted
impl PartialEq for AttachAccepted
Sourceimpl Serialize for AttachAccepted
impl Serialize for AttachAccepted
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for AttachAcceptedwhere
LayoutSnapshot: Serialize<__S>,
PaneRegionsSnapshot: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for AttachAcceptedwhere
LayoutSnapshot: Serialize<__S>,
PaneRegionsSnapshot: Serialize<__S>,
impl StructuralPartialEq for AttachAccepted