pub struct AttachRequest {
pub session: SessionName,
pub terminal_size: TerminalSize,
}Fields
session: SessionNameterminal_size: TerminalSizeTrait Implementations
Sourceimpl Archive for AttachRequestwhere
SessionName: Archive,
TerminalSize: Archive,
impl Archive for AttachRequestwhere
SessionName: Archive,
TerminalSize: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedAttachRequest
type Archived = ArchivedAttachRequest
The archived representation of this type. Read more
Sourcetype Resolver = AttachRequestResolver
type Resolver = AttachRequestResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for AttachRequest
impl Clone for AttachRequest
Sourcefn clone(&self) -> AttachRequest
fn clone(&self) -> AttachRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AttachRequest
impl Debug for AttachRequest
Sourceimpl<__D: Fallible + ?Sized> Deserialize<AttachRequest, __D> for Archived<AttachRequest>where
SessionName: Archive,
<SessionName as Archive>::Archived: Deserialize<SessionName, __D>,
TerminalSize: Archive,
<TerminalSize as Archive>::Archived: Deserialize<TerminalSize, __D>,
impl<__D: Fallible + ?Sized> Deserialize<AttachRequest, __D> for Archived<AttachRequest>where
SessionName: Archive,
<SessionName as Archive>::Archived: Deserialize<SessionName, __D>,
TerminalSize: Archive,
<TerminalSize as Archive>::Archived: Deserialize<TerminalSize, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<AttachRequest, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<AttachRequest, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Eq for AttachRequest
Sourceimpl PartialEq for AttachRequest
impl PartialEq for AttachRequest
Sourceimpl Serialize for AttachRequest
impl Serialize for AttachRequest
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for AttachRequestwhere
SessionName: Serialize<__S>,
TerminalSize: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for AttachRequestwhere
SessionName: Serialize<__S>,
TerminalSize: Serialize<__S>,
impl StructuralPartialEq for AttachRequest