pub struct ClientKey {
pub code: ClientKeyCode,
pub modifiers: ClientKeyModifiers,
pub raw_bytes: Vec<u8>,
}Expand description
One ordered keyboard event from the muxr client.
Fields
code: ClientKeyCodemodifiers: ClientKeyModifiersraw_bytes: Vec<u8>Trait Implementations
Sourceimpl Archive for ClientKey
impl Archive for ClientKey
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedClientKey
type Archived = ArchivedClientKey
The archived representation of this type. Read more
Sourcetype Resolver = ClientKeyResolver
type Resolver = ClientKeyResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl<__D: Fallible + ?Sized> Deserialize<ClientKey, __D> for Archived<ClientKey>where
ClientKeyCode: Archive,
<ClientKeyCode as Archive>::Archived: Deserialize<ClientKeyCode, __D>,
ClientKeyModifiers: Archive,
<ClientKeyModifiers as Archive>::Archived: Deserialize<ClientKeyModifiers, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<ClientKey, __D> for Archived<ClientKey>where
ClientKeyCode: Archive,
<ClientKeyCode as Archive>::Archived: Deserialize<ClientKeyCode, __D>,
ClientKeyModifiers: Archive,
<ClientKeyModifiers as Archive>::Archived: Deserialize<ClientKeyModifiers, __D>,
Vec<u8>: Archive,
<Vec<u8> as Archive>::Archived: Deserialize<Vec<u8>, __D>,
impl Eq for ClientKey
impl StructuralPartialEq for ClientKey