pub struct LayoutSnapshot {
active_tab: TabId,
tabs: Vec<TabSnapshot>,
}Fields
active_tab: TabIdtabs: Vec<TabSnapshot>Implementations
Sourceimpl LayoutSnapshot
impl LayoutSnapshot
Sourcepub fn new(active_tab: TabId, tabs: Vec<TabSnapshot>) -> Result<Self>
pub fn new(active_tab: TabId, tabs: Vec<TabSnapshot>) -> Result<Self>
Build a layout snapshot with active tab and pane invariants checked.
Errors
- Any tab or pane id is duplicated.
- The layout has no tabs.
- The active tab does not exist.
- Any tab has no panes or an active pane that does not exist.
pub const fn active_tab(&self) -> &TabId
pub fn tabs(&self) -> &[TabSnapshot]
fn validate(&self) -> Result<()>