PaneRegionSnapshot

Struct PaneRegionSnapshot 

pub struct PaneRegionSnapshot {
    id: PaneId,
    col: u16,
    row: u16,
    cols: u16,
    mouse_mode: PaneMouseMode,
    rows: u16,
    visible_top_row: u64,
    wrapped_rows: Vec<RowWrap>,
}

Fields

id: PaneIdcol: u16row: u16cols: u16mouse_mode: PaneMouseModerows: u16visible_top_row: u64wrapped_rows: Vec<RowWrap>

Implementations

Source

impl PaneRegionSnapshot

pub fn new( id: PaneId, col: u16, row: u16, cols: u16, rows: u16, mouse_mode: PaneMouseMode, visible_top_row: u64, ) -> Result<Self>

Build a visible pane region for the current rendered frame.

Errors
  • The region has zero columns or rows.
  • The region row or column range overflows.
pub fn with_wrapped_rows(self, wrapped_rows: Vec<RowWrap>) -> Result<Self>

Attach per-visible-row soft-wrap metadata from the pane terminal.

Errors
  • The number of row flags does not match the region height.
pub const fn col(&self) -> u16

pub const fn cols(&self) -> u16

pub const fn id(&self) -> &PaneId

pub const fn mouse_mode(&self) -> PaneMouseMode

Return the pane application’s current terminal mouse tracking mode.

pub const fn row(&self) -> u16

pub const fn rows(&self) -> u16

pub const fn visible_top_row(&self) -> u64

Return the stable content row rendered at the top of this pane’s visible viewport.

pub fn content_row_wrap(&self, content_row: u64) -> RowWrap

Return the soft-wrap metadata for a stable content row in this rendered viewport.

pub const fn containment(&self, row: u16, col: u16) -> PaneRegionContainment

fn validate(&self) -> Result<()>