pub struct RenderStyle {
pub attrs: RenderTextStyle,
pub bg: RenderColor,
pub fg: RenderColor,
}Fields
attrs: RenderTextStylebg: RenderColorfg: RenderColorTrait Implementations
Sourceimpl Archive for RenderStylewhere
RenderTextStyle: Archive,
RenderColor: Archive,
impl Archive for RenderStylewhere
RenderTextStyle: Archive,
RenderColor: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedRenderStyle
type Archived = ArchivedRenderStyle
The archived representation of this type. Read more
Sourcetype Resolver = RenderStyleResolver
type Resolver = RenderStyleResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for RenderStyle
impl Clone for RenderStyle
Sourcefn clone(&self) -> RenderStyle
fn clone(&self) -> RenderStyle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for RenderStyle
Sourceimpl Debug for RenderStyle
impl Debug for RenderStyle
Sourceimpl Default for RenderStyle
impl Default for RenderStyle
Sourcefn default() -> RenderStyle
fn default() -> RenderStyle
Returns the “default value” for a type. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<RenderStyle, __D> for Archived<RenderStyle>where
RenderTextStyle: Archive,
<RenderTextStyle as Archive>::Archived: Deserialize<RenderTextStyle, __D>,
RenderColor: Archive,
<RenderColor as Archive>::Archived: Deserialize<RenderColor, __D>,
impl<__D: Fallible + ?Sized> Deserialize<RenderStyle, __D> for Archived<RenderStyle>where
RenderTextStyle: Archive,
<RenderTextStyle as Archive>::Archived: Deserialize<RenderTextStyle, __D>,
RenderColor: Archive,
<RenderColor as Archive>::Archived: Deserialize<RenderColor, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<RenderStyle, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<RenderStyle, <__D as Fallible>::Error>
Deserializes using the given deserializer
impl Eq for RenderStyle
Sourceimpl PartialEq for RenderStyle
impl PartialEq for RenderStyle
Sourceimpl Serialize for RenderStyle
impl Serialize for RenderStyle
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for RenderStylewhere
RenderTextStyle: Serialize<__S>,
RenderColor: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for RenderStylewhere
RenderTextStyle: Serialize<__S>,
RenderColor: Serialize<__S>,
impl StructuralPartialEq for RenderStyle