pub struct ServerRunnerArgs {
pub external_layout: Option<PathBuf>,
pub session: SessionName,
}Expand description
Private muxr-server argument contract shared by the public CLI, client spawn path, and server runner.
Fields
external_layout: Option<PathBuf>Optional external layout file used only when creating a new session.
session: SessionNameSession name owned by the server runner.
Implementations
Sourceimpl ServerRunnerArgs
impl ServerRunnerArgs
Sourcepub fn parse(args: &[OsString]) -> Result<Self>
pub fn parse(args: &[OsString]) -> Result<Self>
Parse the private server-runner argument contract used by the public muxr CLI.
Errors
- The invocation is missing its session name, has extra args, or has an invalid session name.
Sourcepub fn argv(&self) -> Vec<OsString>
pub fn argv(&self) -> Vec<OsString>
Return argv for muxr-server; keep this symmetric with Self::parse.