pub struct SessionPaths {
pub root: PathBuf,
pub socket: PathBuf,
pub pid: PathBuf,
pub layout: PathBuf,
pub panes: PathBuf,
}Fields
root: PathBufsocket: PathBufpid: PathBuflayout: PathBufpanes: PathBufImplementations
Sourceimpl SessionPaths
impl SessionPaths
Sourcepub fn sessions_root_from_home() -> Result<PathBuf>
pub fn sessions_root_from_home() -> Result<PathBuf>
Return the root directory containing all muxr session directories under $HOME.
Errors
HOMEis unavailable in the current environment.
Sourcepub fn sessions_root_from_home_path(home: PathBuf) -> PathBuf
pub fn sessions_root_from_home_path(home: PathBuf) -> PathBuf
Return the root directory containing all muxr session directories under an explicit home path.
Sourcepub fn from_home(session: &SessionName) -> Result<Self>
pub fn from_home(session: &SessionName) -> Result<Self>
Build muxr session paths under $HOME/.local/state/muxr.
Errors
HOMEis unavailable in the current environment.- The derived Unix socket path is too long for the platform socket address.
Sourcepub fn from_sessions_root_path(
sessions_root: &Path,
session: &SessionName,
) -> Result<Self>
pub fn from_sessions_root_path( sessions_root: &Path, session: &SessionName, ) -> Result<Self>
Build muxr session paths from an explicit sessions root.
Errors
- The sessions root has no parent state directory.
- The derived Unix socket path is too long for the platform socket address.
Sourcepub fn logs_root(&self) -> Result<PathBuf>
pub fn logs_root(&self) -> Result<PathBuf>
Build the centralized directory containing muxr server logs.
Errors
- The session root path has no parent state root.
Sourcepub fn server_log_path(
&self,
session: &SessionName,
timestamp: &ServerLogTimestamp,
pid: u32,
) -> Result<PathBuf>
pub fn server_log_path( &self, session: &SessionName, timestamp: &ServerLogTimestamp, pid: u32, ) -> Result<PathBuf>
Build the centralized server log path for one muxr server process start.
Errors
- The session root path has no parent state root.
Sourcepub fn server_log_file_pattern(session: &SessionName, pid: u32) -> String
pub fn server_log_file_pattern(session: &SessionName, pid: u32) -> String
Return the pid-scoped server log filename pattern used in client startup failure hints.
The timestamp is chosen inside the server, so the client can only know the session name and spawned pid.
fn from_home_path(home: PathBuf, session: &SessionName) -> Result<Self>
fn from_state_root_path( state_root: &Path, session: &SessionName, ) -> Result<Self>
fn state_root_from_home_path(home: PathBuf) -> PathBuf
fn state_root(&self) -> Result<&Path>